@@ -17,7 +17,6 @@ import traceback
 
 from alipcs_py import __version__
 from alipcs_py.alipcs import AliPCSApi, AliPCSError
-from alipcs_py.alipcs.inner import PcsRapidUploadInfo
 from alipcs_py.app.account import Account, AccountManager
 from alipcs_py.commands.env import (
     ACCOUNT_DATA_PATH,
@@ -236,12 +235,6 @@ def _encrypt_password(ctx) -> bytes:
         return b""
 
 
-def _rapiduploadinfo_file(ctx) -> str:
-    """Return global `RapidUploadInfo`"""
-
-    return ctx.obj.rapiduploadinfo_file
-
-
 ALIAS = OrderedDict(
     **{
         # Account
@@ -268,7 +261,6 @@ ALIAS = OrderedDict(
         "S": "share",
         "sl": "shared",
         "cs": "cancelshared",
-        "lsp": "listsharedpaths",
         "s": "save",
     }
 )
@@ -312,18 +304,10 @@ _ALIAS_DOC = "Command 别名:\n\n\b\n" + "\n".join(
     default=ACCOUNT_DATA_PATH,
     help="Account data file",
 )
-@click.option(
-    "--rapiduploadinfo-file",
-    "--rf",
-    type=str,
-    default=RAPIDUPLOADINFO_PATH,
-    help="秒传 sqlite3 文件",
-)
 @click.option("--users", "-u", type=str, default=None, help="用户名片段，用“,”分割")
 @click.pass_context
-def app(ctx, account_data_path, rapiduploadinfo_file, users):
+def app(ctx, account_data_path, users):
     ctx.obj.account_manager = AccountManager.load_data(account_data_path)
-    ctx.obj.rapiduploadinfo_file = str(Path(rapiduploadinfo_file).expanduser())
     ctx.obj.users = [] if users is None else users.split(",")
 
 
@@ -505,6 +489,9 @@ def pwd(ctx):
 @app.command()
 @click.argument("remotepaths", nargs=-1, type=str)
 @click.option("--file-id", "-i", multiple=True, type=str, help="文件 ID")
+@click.option("--share-id", "--si", nargs=1, type=str, help="列出这个分享ID下的文件")
+@click.option("--share-url", "--su", nargs=1, type=str, help="列出这个分享url下的文件")
+@click.option("--password", "-p", type=str, help="分享链接密码，如果没有不用设置")
 @click.option("--desc", "-r", is_flag=True, help="逆序排列文件")
 @click.option("--name", "-n", is_flag=True, help="依名字排序")
 @click.option("--time", "-t", is_flag=True, help="依时间排序")
@@ -520,7 +507,7 @@ def pwd(ctx):
 @click.option("--show-size", "-S", is_flag=True, help="显示文件大小")
 @click.option("--show-date", "-D", is_flag=True, help="显示文件创建时间")
 @click.option("--show-file-id", "--ID", is_flag=True, help="显示文件 ID")
-@click.option("--show-hash", "-H", is_flag=True, help="显示文件md5")
+@click.option("--show-hash", "-H", is_flag=True, help="显示文件 sha1")
 @click.option("--show-absolute-path", "-A", is_flag=True, help="显示文件绝对路径")
 @click.option("--show-dl-link", "--DL", is_flag=True, help="显示文件下载连接")
 @click.option("--csv", is_flag=True, help="用 csv 格式显示，单行显示，推荐和 --DL 或 --HL 一起用")
@@ -532,6 +519,9 @@ def ls(
     ctx,
     remotepaths,
     file_id,
+    share_id,
+    share_url,
+    password,
     desc,
     name,
     time,
@@ -573,35 +563,59 @@ def ls(
     if is_dir:
         sifters.append(IsDirSifter())
 
-    pwd = _pwd(ctx)
-    if not file_id and not remotepaths:
-        remotepaths = [pwd]
-    remotepaths = [join_path(pwd, r) for r in list(remotepaths)]
+    if share_id or share_url:
+        if not file_id and not remotepaths and "folder" not in (share_url or ""):
+            remotepaths = ["/"]
 
-    user_id, user_name = _recent_user_id_and_name(ctx)
+        assert all([r.startswith("/") for r in remotepaths])
 
-    list_files(
-        api,
-        *remotepaths,
-        file_ids=file_id,
-        desc=desc,
-        name=name,
-        time=time,
-        size=size,
-        recursive=recursive,
-        sifters=sifters,
-        highlight=not no_highlight,
-        user_id=user_id,
-        user_name=user_name,
-        show_size=show_size,
-        show_date=show_date,
-        show_file_id=show_file_id,
-        show_hash=show_hash,
-        show_absolute_path=show_absolute_path,
-        show_dl_link=show_dl_link,
-        csv=csv,
-        only_dl_link=only_dl_link,
-    )
+        _share.list_shared_files(
+            api,
+            *remotepaths,
+            share_id=share_id,
+            share_url=share_url,
+            password=password,
+            file_ids=file_id,
+            desc=desc,
+            name=name,
+            time=time,
+            size=size,
+            recursive=recursive,
+            sifters=sifters,
+            highlight=not no_highlight,
+            show_size=show_size,
+            show_date=show_date,
+            show_file_id=show_file_id,
+            show_absolute_path=show_absolute_path,
+            csv=csv,
+        )
+    else:
+        pwd = _pwd(ctx)
+        if not file_id and not remotepaths:
+            remotepaths = [pwd]
+
+        remotepaths = [join_path(pwd, r) for r in list(remotepaths)]
+
+        list_files(
+            api,
+            *remotepaths,
+            file_ids=file_id,
+            desc=desc,
+            name=name,
+            time=time,
+            size=size,
+            recursive=recursive,
+            sifters=sifters,
+            highlight=not no_highlight,
+            show_size=show_size,
+            show_date=show_date,
+            show_file_id=show_file_id,
+            show_hash=show_hash,
+            show_absolute_path=show_absolute_path,
+            show_dl_link=show_dl_link,
+            csv=csv,
+            only_dl_link=only_dl_link,
+        )
 
 
 @app.command()
@@ -615,7 +629,7 @@ def ls(
 @click.option("--no-highlight", "--NH", is_flag=True, help="取消匹配高亮")
 @click.option("--show-size", "-S", is_flag=True, help="显示文件大小")
 @click.option("--show-date", "-D", is_flag=True, help="显示文件创建时间")
-@click.option("--show-hash", "-H", is_flag=True, help="显示文件md5")
+@click.option("--show-hash", "-H", is_flag=True, help="显示文件 sha1")
 @click.option("--csv", is_flag=True, help="用 csv 格式显示")
 @click.pass_context
 @handle_error
@@ -815,6 +829,9 @@ def remove(ctx, remotepaths):
 @click.argument("remotepaths", nargs=-1, type=str)
 @click.option("--file-id", "-i", multiple=True, type=str, help="文件 ID")
 @click.option("--outdir", "-o", nargs=1, type=str, default=".", help="指定下载本地目录，默认为当前目录")
+@click.option("--share-id", "--si", nargs=1, type=str, help="下载这个分享ID下的文件")
+@click.option("--share-url", "--su", nargs=1, type=str, help="下载这个分享url下的文件")
+@click.option("--password", "-p", type=str, help="分享链接密码，如果没有不用设置")
 @click.option("--recursive", "-R", is_flag=True, help="递归下载")
 @click.option(
     "--from-index", "-f", type=int, default=0, help="从所有目录中的第几个文件开始下载，默认为0（第一个）"
@@ -866,6 +883,9 @@ def download(
     remotepaths,
     file_id,
     outdir,
+    share_id,
+    share_url,
+    password,
     recursive,
     from_index,
     include,
@@ -899,34 +919,58 @@ def download(
     if exclude_regex:
         sifters.append(ExcludeSifter(exclude_regex, regex=True))
 
-    pwd = _pwd(ctx)
-    remotepaths = [join_path(pwd, r) for r in remotepaths]
-
     if no_decrypt:
         encrypt_password = b""
     else:
         encrypt_password = encrypt_password or _encrypt_password(ctx)
 
-    _download(
-        api,
-        remotepaths,
-        file_id,
-        outdir,
-        sifters=sifters,
-        recursive=recursive,
-        from_index=from_index,
-        downloader=getattr(Downloader, downloader),
-        downloadparams=DownloadParams(
-            concurrency=concurrency, chunk_size=chunk_size, quiet=quiet
-        ),
-        out_cmd=out_cmd,
-        encrypt_password=encrypt_password,
-    )
+    if share_id or share_url:
+        assert all([r.startswith("/") for r in remotepaths])
+
+        _share.download_shared(
+            api,
+            remotepaths,
+            file_id,
+            outdir,
+            share_id=share_id,
+            share_url=share_url,
+            password=password,
+            sifters=sifters,
+            recursive=recursive,
+            from_index=from_index,
+            downloader=getattr(Downloader, downloader),
+            downloadparams=DownloadParams(
+                concurrency=concurrency, chunk_size=chunk_size, quiet=quiet
+            ),
+            out_cmd=out_cmd,
+            encrypt_password=encrypt_password,
+        )
+    else:
+        pwd = _pwd(ctx)
+        remotepaths = [join_path(pwd, r) for r in remotepaths]
+        _download(
+            api,
+            remotepaths,
+            file_id,
+            outdir,
+            sifters=sifters,
+            recursive=recursive,
+            from_index=from_index,
+            downloader=getattr(Downloader, downloader),
+            downloadparams=DownloadParams(
+                concurrency=concurrency, chunk_size=chunk_size, quiet=quiet
+            ),
+            out_cmd=out_cmd,
+            encrypt_password=encrypt_password,
+        )
 
 
 @app.command()
 @click.argument("remotepaths", nargs=-1, type=str)
 @click.option("--file-id", "-i", multiple=True, type=str, help="文件 ID")
+@click.option("--share-id", "--si", nargs=1, type=str, help="播放这个分享ID下的文件")
+@click.option("--share-url", "--su", nargs=1, type=str, help="播放这个分享url下的文件")
+@click.option("--password", "-p", type=str, help="分享链接密码，如果没有不用设置")
 @click.option("--recursive", "-R", is_flag=True, help="递归播放")
 @click.option(
     "--from-index", "-f", type=int, default=0, help="从所有目录中的第几个文件开始播放，默认为0（第一个）"
@@ -962,6 +1006,9 @@ def play(
     ctx,
     remotepaths,
     file_id,
+    share_id,
+    share_url,
+    password,
     recursive,
     from_index,
     include,
@@ -993,9 +1040,6 @@ def play(
     if exclude_regex:
         sifters.append(ExcludeSifter(exclude_regex, regex=True))
 
-    pwd = _pwd(ctx)
-    remotepaths = [join_path(pwd, r) for r in remotepaths]
-
     local_server = ""
     if use_local_server:
         encrypt_password = encrypt_password or _encrypt_password(ctx)
@@ -1022,21 +1066,45 @@ def play(
         ps.start()
         time.sleep(1)
 
-    _play(
-        api,
-        remotepaths,
-        file_ids=file_id,
-        sifters=sifters,
-        recursive=recursive,
-        from_index=from_index,
-        player=getattr(Player, player),
-        player_params=player_params,
-        quiet=quiet,
-        shuffle=shuffle,
-        ignore_ext=ignore_ext,
-        out_cmd=out_cmd,
-        local_server=local_server,
-    )
+    if share_id or share_url:
+        assert all([r.startswith("/") for r in remotepaths])
+
+        _share.play_shared(
+            api,
+            remotepaths,
+            file_ids=file_id,
+            share_id=share_id,
+            share_url=share_url,
+            password=password,
+            sifters=sifters,
+            recursive=recursive,
+            from_index=from_index,
+            player=getattr(Player, player),
+            player_params=player_params,
+            quiet=quiet,
+            shuffle=shuffle,
+            ignore_ext=ignore_ext,
+            out_cmd=out_cmd,
+            local_server=local_server,
+        )
+    else:
+        pwd = _pwd(ctx)
+        remotepaths = [join_path(pwd, r) for r in list(remotepaths)]
+        _play(
+            api,
+            remotepaths,
+            file_ids=file_id,
+            sifters=sifters,
+            recursive=recursive,
+            from_index=from_index,
+            player=getattr(Player, player),
+            player_params=player_params,
+            quiet=quiet,
+            shuffle=shuffle,
+            ignore_ext=ignore_ext,
+            out_cmd=out_cmd,
+            local_server=local_server,
+        )
 
     if use_local_server:
         ps.terminate()
@@ -1097,10 +1165,6 @@ def upload(
     pwd = _pwd(ctx)
     remotedir = join_path(pwd, remotedir)
 
-    rapiduploadinfo_file = _rapiduploadinfo_file(ctx)
-
-    user_id, user_name = _recent_user_id_and_name(ctx)
-
     from_to_list = from_tos(localpaths, remotedir)
     _upload(
         api,
@@ -1111,9 +1175,6 @@ def upload(
         max_workers=max_workers,
         ignore_existing=not no_ignore_existing,
         show_progress=not no_show_progress,
-        rapiduploadinfo_file=rapiduploadinfo_file,
-        user_id=user_id,
-        user_name=user_name,
     )
 
 
@@ -1160,10 +1221,6 @@ def sync(
     if encrypt_type != EncryptType.No.name and not encrypt_password:
         raise ValueError(f"Encrypting with {encrypt_type} must have a key")
 
-    rapiduploadinfo_file = _rapiduploadinfo_file(ctx)
-
-    user_id, user_name = _recent_user_id_and_name(ctx)
-
     _sync(
         api,
         localdir,
@@ -1172,9 +1229,6 @@ def sync(
         encrypt_type=getattr(EncryptType, encrypt_type),
         max_workers=max_workers,
         show_progress=not no_show_progress,
-        rapiduploadinfo_file=rapiduploadinfo_file,
-        user_id=user_id,
-        user_name=user_name,
     )
 
 
@@ -1185,7 +1239,7 @@ def sync(
 # {{{
 @app.command()
 @click.argument("remotepaths", nargs=-1, type=str)
-@click.option("--password", "-p", type=str, default="", help="设置秘密，4个字符。默认没有秘密")
+@click.option("--password", "-p", type=str, default="", help="设置秘密，默认没有秘密")
 @click.option("--period-time", "--pt", type=int, default=0, help="设置分享有效期，单位为天")
 @click.pass_context
 @handle_error
@@ -1239,30 +1293,14 @@ def cancelshared(ctx, share_ids):
 
 
 @app.command()
-@click.argument("shared_url", nargs=1, type=str)
-@click.option("--password", "-p", type=str, help="链接密码，如果没有不用设置")
-@click.pass_context
-@handle_error
-@multi_user_do
-def listsharedpaths(ctx, shared_url, password):
-    """列出其他用户分享链接中的文件"""
-
-    api = _recent_api(ctx)
-    if not api:
-        return
-
-    _share.list_shared_files(api, shared_url, password=password)
-
-
-@app.command()
-@click.argument("shared_url", nargs=1, type=str)
+@click.argument("share_url_or_id", nargs=1, type=str)
 @click.argument("remotedir", nargs=1, type=str)
-@click.option("--share-id", "-i", type=str, help="分享连接 ID")
-@click.option("--password", "-p", type=str, help="链接密码，如果没有不用设置")
+@click.option("--file-id", "-i", multiple=True, type=str, help="文件 ID")
+@click.option("--password", "-p", type=str, help="分享链接密码，如果没有不用设置")
 @click.pass_context
 @handle_error
 @multi_user_do
-def save(ctx, shared_url, remotedir, share_id, password):
+def save(ctx, share_url_or_id, file_id, remotedir, password):
     """保存其他用户分享的链接"""
 
     api = _recent_api(ctx)
@@ -1272,8 +1310,20 @@ def save(ctx, shared_url, remotedir, share_id, password):
     pwd = _pwd(ctx)
     remotedir = join_path(pwd, remotedir)
 
+    share_url = ""
+    share_id = ""
+    if "/s/" in share_url_or_id:
+        share_url = share_url_or_id
+    else:
+        share_id = share_url_or_id
+
     _share.save_shared(
-        api, remotedir, shared_url=shared_url, share_id=share_id, password=password
+        api,
+        remotedir,
+        share_id=share_id,
+        share_url=share_url,
+        file_ids=file_id,
+        password=password,
     )
 
 
